package com.goldenwater.slaj.eutr.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.eutr.mapper.ObjEutrCourMapper;
import com.goldenwater.slaj.eutr.domain.ObjEutrCour;
import com.goldenwater.slaj.eutr.service.IObjEutrCourService;

@Service
public class ObjEutrCourServiceImpl implements IObjEutrCourService {
    @Autowired
    private ObjEutrCourMapper objEutrCourMapper;

    @Override
    public ObjEutrCour selectObjEutrCourByGuid(String guid) {
        return objEutrCourMapper.selectObjEutrCourByGuid(guid);
    }

    @Override
    public List<ObjEutrCour> selectObjEutrCourList(ObjEutrCour objEutrCour) {
        return objEutrCourMapper.selectObjEutrCourList(objEutrCour);
    }

    @Override
    public int insertObjEutrCour(ObjEutrCour objEutrCour) {
        return objEutrCourMapper.insertObjEutrCour(objEutrCour);
    }

    @Override
    public int updateObjEutrCour(ObjEutrCour objEutrCour) {
        return objEutrCourMapper.updateObjEutrCour(objEutrCour);
    }

    @Override
    public int deleteObjEutrCourByGuid(String guid) {
        return objEutrCourMapper.deleteObjEutrCourByGuid(guid);
    }

    @Override
    public int deleteObjEutrCourByGuids(String[] guids) {
        return objEutrCourMapper.deleteObjEutrCourByGuids(guids);
    }
}
