package com.goldenwater.slaj.eutr.controller;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.goldenwater.common.annotation.Log;
import com.goldenwater.common.core.controller.BaseController;
import com.goldenwater.common.core.domain.AjaxResult;
import com.goldenwater.common.core.page.TableDataInfo;
import com.goldenwater.common.enums.BusinessType;
import com.goldenwater.common.utils.poi.ExcelUtil;
import com.goldenwater.slaj.eutr.domain.ObjEutrCour;
import com.goldenwater.slaj.eutr.service.IObjEutrCourService;

@RestController
@RequestMapping("/eutr/objcour")
public class ObjEutrCourController extends BaseController {
    @Autowired
    private IObjEutrCourService objEutrCourService;

    @GetMapping("/list")
    public TableDataInfo list(ObjEutrCour objEutrCour) {
        startPage();
        List<ObjEutrCour> list = objEutrCourService.selectObjEutrCourList(objEutrCour);
        return getDataTable(list);
    }

    @GetMapping("/{guid}")
    public AjaxResult getInfo(@PathVariable String guid) {
        return AjaxResult.success(objEutrCourService.selectObjEutrCourByGuid(guid));
    }

    @PostMapping
    public AjaxResult add(@RequestBody ObjEutrCour objEutrCour) {
        return toAjax(objEutrCourService.insertObjEutrCour(objEutrCour));
    }

    @PutMapping
    public AjaxResult edit(@RequestBody ObjEutrCour objEutrCour) {
        return toAjax(objEutrCourService.updateObjEutrCour(objEutrCour));
    }

    @DeleteMapping("/{guids}")
    public AjaxResult remove(@PathVariable String[] guids) {
        return toAjax(objEutrCourService.deleteObjEutrCourByGuids(guids));
    }

    @Log(title = "培训课程管理", businessType = BusinessType.EXPORT)
    @PreAuthorize("@ss.hasPermi('eutr:objcour:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, ObjEutrCour objEutrCour) {
        List<ObjEutrCour> list = objEutrCourService.selectObjEutrCourList(objEutrCour);
        ExcelUtil<ObjEutrCour> util = new ExcelUtil<ObjEutrCour>(ObjEutrCour.class);
        util.exportExcel(response, list, "培训课程数据");
    }
}
